@@ -399,10 +399,21 @@ OpenSSL::TransceiverI::initialize(IceInternal::Buffer& readBuffer, IceInternal::
             }
             case SSL_ERROR_SSL:
             {
-                ostringstream ostr;
-                ostr << "SSL error occurred for new " << (_incoming ? "incoming" : "outgoing")
-                     << " connection:\n" << _delegate->toString() << "\n" << _engine->sslErrors();
-                throw ProtocolException(__FILE__, __LINE__, ostr.str());
+#if defined(SSL_R_UNEXPECTED_EOF_WHILE_READING)
+                if (SSL_R_UNEXPECTED_EOF_WHILE_READING == ERR_GET_REASON(ERR_get_error()))
+                {
+                    throw ConnectionLostException(__FILE__, __LINE__, 0);
+                }
+                else
+                {
+#endif
+                    ostringstream ostr;
+                    ostr << "SSL error occurred for new " << (_incoming ? "incoming" : "outgoing")
+                         << " connection:\n" << _delegate->toString() << "\n" << _engine->sslErrors();
+                    throw ProtocolException(__FILE__, __LINE__, ostr.str());
+#if defined(SSL_R_UNEXPECTED_EOF_WHILE_READING)
+                }
+#endif
             }
             }
         }
@@ -748,8 +759,19 @@ OpenSSL::TransceiverI::read(IceInternal::Buffer& buf)
             }
             case SSL_ERROR_SSL:
             {
-                throw ProtocolException(__FILE__, __LINE__,
-                                        "SSL protocol error during read:\n" + _engine->sslErrors());
+#if defined(SSL_R_UNEXPECTED_EOF_WHILE_READING)
+                if (SSL_R_UNEXPECTED_EOF_WHILE_READING == ERR_GET_REASON(ERR_get_error()))
+                {
+                    throw ConnectionLostException(__FILE__, __LINE__, 0);
+                }
+                else
+                {
+#endif
+                    throw ProtocolException(__FILE__, __LINE__,
+                                            "SSL protocol error during read:\n" + _engine->sslErrors());
+#if defined(SSL_R_UNEXPECTED_EOF_WHILE_READING)
+                }
+#endif
             }
             }
         }
