@@ -20,6 +20,10 @@ using namespace std;
 using namespace Ice;
 using namespace IceSSL;
 
+#ifndef CERT_CHAIN_DISABLE_AIA
+#   define CERT_CHAIN_DISABLE_AIA 0x00002000
+#endif
+
 namespace
 {
 
@@ -55,13 +59,25 @@ trustStatusToTrustError(DWORD status)
     {
         return IceSSL::ICE_ENUM(TrustError, NoError);
     }
-    if (status & CERT_TRUST_IS_NOT_TIME_VALID)
+    if ((status & CERT_TRUST_IS_UNTRUSTED_ROOT) ||
+        (status & CERT_TRUST_IS_CYCLIC) ||
+        (status & CERT_TRUST_CTL_IS_NOT_TIME_VALID) ||
+        (status & CERT_TRUST_CTL_IS_NOT_SIGNATURE_VALID) ||
+        (status & CERT_TRUST_CTL_IS_NOT_VALID_FOR_USAGE))
     {
-        return IceSSL::ICE_ENUM(TrustError, InvalidTime);
+        return IceSSL::ICE_ENUM(TrustError, UntrustedRoot);
     }
-    if (status & CERT_TRUST_IS_REVOKED)
+    if (status & CERT_TRUST_IS_EXPLICIT_DISTRUST)
     {
-        return IceSSL::ICE_ENUM(TrustError, Revoked);
+        return IceSSL::ICE_ENUM(TrustError, NotTrusted);
+    }
+    if (status & CERT_TRUST_IS_PARTIAL_CHAIN)
+    {
+        return IceSSL::ICE_ENUM(TrustError, PartialChain);
+    }
+    if (status & CERT_TRUST_INVALID_BASIC_CONSTRAINTS)
+    {
+        return IceSSL::ICE_ENUM(TrustError, InvalidBasicConstraints);
     }
     if (status & CERT_TRUST_IS_NOT_SIGNATURE_VALID)
     {
@@ -71,17 +87,9 @@ trustStatusToTrustError(DWORD status)
     {
         return IceSSL::ICE_ENUM(TrustError, InvalidPurpose);
     }
-    if ((status & CERT_TRUST_IS_UNTRUSTED_ROOT) ||
-        (status & CERT_TRUST_IS_CYCLIC) ||
-        (status & CERT_TRUST_CTL_IS_NOT_TIME_VALID) ||
-        (status & CERT_TRUST_CTL_IS_NOT_SIGNATURE_VALID) ||
-        (status & CERT_TRUST_CTL_IS_NOT_VALID_FOR_USAGE))
+    if (status & CERT_TRUST_IS_REVOKED)
     {
-        return IceSSL::ICE_ENUM(TrustError, UntrustedRoot);
-    }
-    if (status & CERT_TRUST_REVOCATION_STATUS_UNKNOWN)
-    {
-        return IceSSL::ICE_ENUM(TrustError, RevocationStatusUnknown);
+        return IceSSL::ICE_ENUM(TrustError, Revoked);
     }
     if (status & CERT_TRUST_INVALID_EXTENSION)
     {
@@ -91,10 +99,6 @@ trustStatusToTrustError(DWORD status)
     {
         return IceSSL::ICE_ENUM(TrustError, InvalidPolicyConstraints);
     }
-    if (status & CERT_TRUST_INVALID_BASIC_CONSTRAINTS)
-    {
-        return IceSSL::ICE_ENUM(TrustError, InvalidBasicConstraints);
-    }
     if (status & CERT_TRUST_INVALID_NAME_CONSTRAINTS)
     {
         return IceSSL::ICE_ENUM(TrustError, InvalidNameConstraints);
@@ -115,25 +119,22 @@ trustStatusToTrustError(DWORD status)
     {
         return IceSSL::ICE_ENUM(TrustError, HasExcludedNameConstraint);
     }
-    if (status & CERT_TRUST_IS_OFFLINE_REVOCATION)
-    {
-        return IceSSL::ICE_ENUM(TrustError, RevocationStatusUnknown);
-    }
     if (status & CERT_TRUST_NO_ISSUANCE_CHAIN_POLICY)
     {
         return IceSSL::ICE_ENUM(TrustError, InvalidPolicyConstraints);
     }
-    if (status & CERT_TRUST_IS_EXPLICIT_DISTRUST)
-    {
-        return IceSSL::ICE_ENUM(TrustError, NotTrusted);
-    }
     if (status & CERT_TRUST_HAS_NOT_SUPPORTED_CRITICAL_EXT)
     {
         return IceSSL::ICE_ENUM(TrustError, HasNonSupportedCriticalExtension);
     }
-    if (status & CERT_TRUST_IS_PARTIAL_CHAIN)
+    if (status & CERT_TRUST_IS_OFFLINE_REVOCATION ||
+        status & CERT_TRUST_REVOCATION_STATUS_UNKNOWN)
     {
-        return IceSSL::ICE_ENUM(TrustError, PartialChain);
+        return IceSSL::ICE_ENUM(TrustError, RevocationStatusUnknown);
+    }
+    if (status & CERT_TRUST_IS_NOT_TIME_VALID)
+    {
+        return IceSSL::ICE_ENUM(TrustError, InvalidTime);
     }
     return IceSSL::ICE_ENUM(TrustError, UnknownTrustFailure);
 }
@@ -765,8 +766,22 @@ SChannel::TransceiverI::initialize(IceInternal::Buffer& readBuffer, IceInternal:
 
         string trustError;
         PCCERT_CHAIN_CONTEXT certChain;
-        if(!CertGetCertificateChain(_engine->chainEngine(), cert, 0, cert->hCertStore, &chainP,
-                                    CERT_CHAIN_REVOCATION_CHECK_CACHE_ONLY, 0, &certChain))
+        DWORD dwFlags = 0;
+        int revocationCheck = _engine->getRevocationCheck();
+        if(revocationCheck > 0)
+        {
+            if(_engine->getRevocationCheckCacheOnly())
+            {
+                // Disable network I/O for revocation checks.
+                dwFlags = CERT_CHAIN_REVOCATION_CHECK_CACHE_ONLY | CERT_CHAIN_DISABLE_AIA;
+            }
+
+            dwFlags |= (revocationCheck == 1 ?
+                        CERT_CHAIN_REVOCATION_CHECK_END_CERT :
+                        CERT_CHAIN_REVOCATION_CHECK_CHAIN_EXCLUDE_ROOT);
+        }
+
+        if(!CertGetCertificateChain(_engine->chainEngine(), cert, 0, cert->hCertStore, &chainP, dwFlags, 0, &certChain))
         {
             CertFreeCertificateContext(cert);
             trustError = IceUtilInternal::lastErrorToString();
