@@ -8,6 +8,8 @@ import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.List;
 import java.security.cert.*;
+import javax.net.ssl.SNIHostName;
+import javax.net.ssl.SNIServerName;
 import javax.net.ssl.SSLParameters;
 import com.zeroc.Ice.PluginInitializationException;
 
@@ -87,6 +89,12 @@ class SSLEngine
         //
         _checkCertName = properties.getPropertyAsIntWithDefault(prefix + "CheckCertName", 0) > 0;
 
+        //
+        // CheckCertName > 1 enables SNI, the SNI extension applies to client connections,
+        // indicating the hostname to the server (must be DNS hostname, not an IP address).
+        //
+        _serverNameIndication = properties.getPropertyAsIntWithDefault(prefix + "CheckCertName", 0) > 1;
+
         //
         // VerifyDepthMax establishes the maximum length of a peer's certificate
         // chain, including the peer's certificate. A value of 0 means there is
@@ -877,6 +885,25 @@ class SSLEngine
             }
         }
 
+        // Server name indication
+        if(!incoming && _serverNameIndication)
+        {
+            SNIHostName serverName = null;
+            try
+            {
+                serverName = new SNIHostName(host);
+                SSLParameters sslParams = engine.getSSLParameters();
+                List<SNIServerName> serverNames = new ArrayList<>();
+                serverNames.add(serverName);
+                sslParams.setServerNames(serverNames);
+                engine.setSSLParameters(sslParams);
+            }
+            catch(IllegalArgumentException ex)
+            {
+                // Invalid SNI hostname, ignore because it might be an IP
+            }
+        }
+
         try
         {
             engine.beginHandshake();
@@ -1191,6 +1218,7 @@ class SSLEngine
     private boolean _noCiphers;
     private String[] _protocols;
     private boolean _checkCertName;
+    private boolean _serverNameIndication;
     private int _verifyDepthMax;
     private int _verifyPeer;
     private CertificateVerifier _verifier;
