@@ -172,14 +172,15 @@ public class ControllerApp extends Application
 
     public static boolean isEmulator()
     {
-        return Build.FINGERPRINT.startsWith("generic") ||
-               Build.FINGERPRINT.startsWith("unknown") ||
-               Build.MODEL.contains("google_sdk") ||
-               Build.MODEL.contains("Emulator") ||
-               Build.MODEL.contains("Android SDK built for x86") ||
-               Build.MANUFACTURER.contains("Genymotion") ||
-               (Build.BRAND.startsWith("generic") && Build.DEVICE.startsWith("generic")) ||
-               Build.PRODUCT.equals("google_sdk");
+        return Build.FINGERPRINT.startsWith("google/sdk_gphone") ||
+            Build.FINGERPRINT.startsWith("generic") ||
+            Build.FINGERPRINT.startsWith("unknown") ||
+            Build.MODEL.contains("google_sdk") ||
+            Build.MODEL.contains("Emulator") ||
+            Build.MODEL.contains("Android SDK built for x86") ||
+            Build.MANUFACTURER.contains("Genymotion") ||
+            (Build.BRAND.startsWith("generic") && Build.DEVICE.startsWith("generic")) ||
+            Build.PRODUCT.equals("google_sdk");
     }
 
     class ControllerI
