@@ -1997,7 +1997,7 @@ twowaysAMI(id<ICECommunicator> communicator, id<TestOperationsMyClassPrx> p)
             [ctx setObject:@"THREE" forKey:@"three"];
 
             id<TestOperationsMyClassPrx> pc = [TestOperationsMyClassPrx uncheckedCast:
-                                                                    [ic stringToProxy:@"test:default -p 12010"]];
+                                                                    [ic stringToProxy:[NSString stringWithFormat:@"test:%@", getTestEndpoint(communicator, 0)]]];
 
             [[ic getImplicitContext] setContext:(ctx)];
             test([[[ic getImplicitContext] getContext] isEqualToDictionary:ctx]);
