@@ -13,6 +13,17 @@ class ConfigurationTestCase(ClientServerTestCase):
             return
 
         certsPath = os.path.abspath(os.path.join(current.testsuite.getPath(), "..", "certs"))
+
+        self.crlServer = None
+        self.ocspServer = None
+
+        if isinstance(platform, Windows) or isinstance(platform, Darwin):
+            from scripts.tests.IceSSL import revocationutil
+            self.crlServer = revocationutil.createCRLServer('127.0.0.1', 20001, certsPath)
+            self.crlServer.start()
+            self.ocspServer = revocationutil.createOCSPServer('127.0.0.1', 20002, certsPath)
+            self.ocspServer.start()
+
         if isinstance(platform, Darwin) and current.config.buildPlatform == "macosx":
             keychainPath = os.path.join(certsPath, "Find.keychain")
             os.system("mkdir -p {0}".format(os.path.join(certsPath, "keychain")))
@@ -41,6 +52,11 @@ class ConfigurationTestCase(ClientServerTestCase):
         if not isinstance(self.getMapping(), CppMapping):
             return
 
+        if self.crlServer:
+            self.crlServer.shutdown()
+        if self.ocspServer:
+            self.ocspServer.shutdown()
+
         certsPath = os.path.abspath(os.path.join(current.testsuite.getPath(), "..", "certs"))
         if isinstance(platform, Darwin) and current.config.buildPlatform == "macosx":
             os.system("rm -rf {0} {1}".format(os.path.join(certsPath, "keychain"), os.path.join(certsPath, "Find.keychain")))
@@ -56,7 +72,7 @@ class ConfigurationTestCase(ClientServerTestCase):
     def getOpenSSLCommand(self, current):
         if isinstance(platform, Windows):
             return os.path.join(current.testsuite.getPath(), "..", "..", "..", "msbuild", "packages",
-                                "zeroc.openssl.v140.1.1.1", "build", "native", "bin", "Win32", "Release",
+                                "zeroc.openssl.v140.1.1.1.2", "build", "native", "bin", "Win32", "Release",
                                 "openssl.exe")
         else:
             return "openssl"
@@ -74,16 +90,12 @@ class IceSSLConfigurationServer(Server):
         if isinstance(platform, Windows) and current.config.openssl:
             return "serveropenssl"
         return Server.getExe(self, current)
-
-# Filter-out the deprecated property warnings
-outfilters = [ lambda x: re.sub("-! .* warning: deprecated property: IceSSL.KeyFile\n", "", x) ]
-
 #
 # With UWP, we can't run this test with the UWP C++ server (used with tcp/ws)
 #
 options=lambda current: { "protocol": ["ssl", "wss"] } if current.config.uwp else {}
 
 TestSuite(__name__, [
-   ConfigurationTestCase(client=IceSSLConfigurationClient(outfilters=outfilters, args=['"{testdir}"']),
-                         server=IceSSLConfigurationServer(outfilters=outfilters, args=['"{testdir}"']))
+   ConfigurationTestCase(client=IceSSLConfigurationClient(args=['"{testdir}"']),
+                         server=IceSSLConfigurationServer(args=['"{testdir}"']))
 ], multihost=False, options=options)
